@@ -5,7 +5,7 @@ related utilities used by hledger commands.
 
 -}
 
-{-# LANGUAGE CPP, ScopedTypeVariables, DeriveDataTypeable, FlexibleContexts, TypeFamilies, OverloadedStrings #-}
+{-# LANGUAGE CPP, ScopedTypeVariables, DeriveDataTypeable, FlexibleContexts, TypeFamilies, OverloadedStrings, PackageImports #-}
 
 module Hledger.Cli.CliOptions (
 
@@ -44,7 +44,6 @@ module Hledger.Cli.CliOptions (
   -- possibly these should move into argsToCliOpts
   -- * CLI option accessors
   -- | These do the extra processing required for some options.
-  aliasesFromOpts,
   journalFilePathFromOpts,
   rulesFilePathFromOpts,
   outputFileFromOpts,
@@ -54,7 +53,6 @@ module Hledger.Cli.CliOptions (
   replaceNumericFlags,
   -- | For register:
   registerWidthsFromOpts,
-  maybeAccountNameDrop,
   -- | For balance:
   lineFormatFromOpts,
 
@@ -73,22 +71,20 @@ module Hledger.Cli.CliOptions (
 where
 
 import Prelude ()
-import Prelude.Compat
+import "base-compat-batteries" Prelude.Compat
 import qualified Control.Exception as C
 import Control.Monad (when)
 import Data.Char
 import Data.Default
-#if !MIN_VERSION_base(4,8,0)
-import Data.Functor.Compat ((<$>))
-#endif
 import Data.Functor.Identity (Identity)
-import Data.List.Compat
+import "base-compat-batteries" Data.List.Compat
 import Data.List.Split (splitOneOf)
 import Data.Ord
 import Data.Maybe
 --import Data.String.Here
 -- import Data.Text (Text)
 import qualified Data.Text as T
+import Data.Void (Void)
 import Safe
 import System.Console.CmdArgs hiding (Default,def)
 import System.Console.CmdArgs.Explicit
@@ -101,7 +97,8 @@ import System.Environment
 import System.Exit (exitSuccess)
 import System.FilePath
 import Test.HUnit
-import Text.Megaparsec.Compat
+import Text.Megaparsec
+import Text.Megaparsec.Char
 
 import Hledger
 import Hledger.Cli.DocFiles
@@ -152,7 +149,7 @@ reportflags = [
  ,flagNone ["cleared","C"]   (setboolopt "cleared") "include only cleared postings/txns"
  ,flagNone ["real","R"]      (setboolopt "real") "include only non-virtual postings"
  ,flagReq  ["depth"]         (\s opts -> Right $ setopt "depth" s opts) "NUM" "(or -NUM): hide accounts/postings deeper than this"
- ,flagNone ["empty","E"]     (setboolopt "empty") "show items with zero amount, normally hidden"
+ ,flagNone ["empty","E"]     (setboolopt "empty") "show items with zero amount, normally hidden (and vice-versa in hledger-ui/hledger-web)"
  ,flagNone ["cost","B"]      (setboolopt "cost") "convert amounts to their cost at transaction time (using the transaction price, if any)"
  ,flagNone ["value","V"]     (setboolopt "value") "convert amounts to their market value on the report end date (using the most recent applicable market price, if any)"
  ,flagNone ["auto"]          (setboolopt "auto") "apply automated posting rules to modify transactions"
@@ -161,7 +158,7 @@ reportflags = [
 
 -- | Common output-related flags: --output-file, --output-format...
 outputflags = [outputFormatFlag, outputFileFlag]
-outputFormatFlag = flagReq  ["output-format","O"] (\s opts -> Right $ setopt "output-format" s opts) "FMT" "select the output format. Supported formats:\ntxt, csv."
+outputFormatFlag = flagReq  ["output-format","O"] (\s opts -> Right $ setopt "output-format" s opts) "FMT" "select the output format. Supported formats:\ntxt, csv, html."
 outputFileFlag   = flagReq  ["output-file","o"]   (\s opts -> Right $ setopt "output-file" s opts) "FILE" "write output to FILE. A file extension matching one of the above formats selects that format."
 
 argsFlag :: FlagHelp -> Arg RawOpts
@@ -286,7 +283,7 @@ standardAddonsHelp = [
   ,("web", "start the web interface")
   ,("accounts", "list account names")
   ,("balance-csv", "output a balance report as CSV")
-  ,("equity", "show a transaction entry zeroing all accounts")
+  ,("close", "show a transaction entry zeroing all accounts")
   ,("print-unique", "print only transactions with unique descriptions")
   ,("register-csv", "output a register report as CSV")
   ,("rewrite", "add specified postings to matched transaction entries")
@@ -484,11 +481,6 @@ getHledgerCliOpts mode' = do
 
 -- CliOpts accessors
 
--- | Get the account name aliases from options, if any.
-aliasesFromOpts :: CliOpts -> [AccountAlias]
-aliasesFromOpts = map (\a -> fromparse $ runParser accountaliasp ("--alias "++quoteIfNeeded a) $ T.pack a)
-                  . aliases_ . inputopts_
-
 -- | Get the (tilde-expanded, absolute) journal file path from
 -- 1. options, 2. an environment variable, or 3. the default.
 -- Actually, returns one or more file paths. There will be more
@@ -524,6 +516,7 @@ defaultOutputFormat = "txt"
 outputFormats =
   [defaultOutputFormat] ++
   ["csv"
+  ,"html"
   ]
 
 -- | Get the output format from the --output-format option,
@@ -560,7 +553,7 @@ rulesFilePathFromOpts opts = do
 widthFromOpts :: CliOpts -> Int
 widthFromOpts CliOpts{width_=Nothing, available_width_=w} = w
 widthFromOpts CliOpts{width_=Just s}  =
-    case runParser (read `fmap` some digitChar <* eof :: ParsecT MPErr String Identity Int) "(unknown)" s of
+    case runParser (read `fmap` some digitChar <* eof :: ParsecT Void String Identity Int) "(unknown)" s of
         Left e   -> usageError $ "could not parse width option: "++show e
         Right w  -> w
 
@@ -582,18 +575,13 @@ registerWidthsFromOpts CliOpts{width_=Just s}  =
         Left e   -> usageError $ "could not parse width option: "++show e
         Right ws -> ws
     where
-        registerwidthp :: (Stream s, Char ~ Token s) => ParsecT MPErr s m (Int, Maybe Int)
+        registerwidthp :: (Stream s, Char ~ Token s) => ParsecT Void s m (Int, Maybe Int)
         registerwidthp = do
           totalwidth <- read `fmap` some digitChar
           descwidth <- optional (char ',' >> read `fmap` some digitChar)
           eof
           return (totalwidth, descwidth)
 
--- | Drop leading components of accounts names as specified by --drop, but only in --flat mode.
-maybeAccountNameDrop :: ReportOpts -> AccountName -> AccountName
-maybeAccountNameDrop opts a | tree_ opts = a
-                            | otherwise  = accountNameDrop (drop_ opts) a
-
 -- for balance, currently:
 
 -- | Parse the format option if provided, possibly returning an error,
@@ -676,10 +664,10 @@ isHledgerExeName :: String -> Bool
 isHledgerExeName = isRight . parsewith hledgerexenamep . T.pack
     where
       hledgerexenamep = do
-        _ <- mptext $ T.pack progname
+        _ <- string $ T.pack progname
         _ <- char '-'
         _ <- some $ noneOf ['.']
-        optional (string "." >> choice' (map (mptext . T.pack) addonExtensions))
+        optional (string "." >> choice' (map (string . T.pack) addonExtensions))
         eof
 
 stripAddonExtension :: String -> String
