@@ -4,6 +4,7 @@ hledger's built-in commands, and helpers for printing the commands list.
 
 {-# LANGUAGE OverloadedStrings #-}
 {-# LANGUAGE QuasiQuotes #-}
+{-# LANGUAGE CPP #-}
 
 module Hledger.Cli.Commands (
    findCommand
@@ -20,7 +21,7 @@ module Hledger.Cli.Commands (
   ,module Hledger.Cli.Commands.Cashflow
   ,module Hledger.Cli.Commands.Checkdates
   ,module Hledger.Cli.Commands.Checkdupes
-  ,module Hledger.Cli.Commands.Equity
+  ,module Hledger.Cli.Commands.Close
   ,module Hledger.Cli.Commands.Help
   ,module Hledger.Cli.Commands.Import
   ,module Hledger.Cli.Commands.Incomestatement
@@ -36,9 +37,12 @@ module Hledger.Cli.Commands (
 where
 
 import Control.Monad
+import Data.Default
 import Data.List
 import Data.List.Split (splitOn)
+#if !(MIN_VERSION_base(4,11,0))
 import Data.Monoid ((<>))
+#endif
 import Data.String.Here
 import Data.Text (Text)
 import qualified Data.Text as T
@@ -59,7 +63,7 @@ import Hledger.Cli.Commands.Balancesheetequity
 import Hledger.Cli.Commands.Cashflow
 import Hledger.Cli.Commands.Checkdates
 import Hledger.Cli.Commands.Checkdupes
-import Hledger.Cli.Commands.Equity
+import Hledger.Cli.Commands.Close
 import Hledger.Cli.Commands.Help
 import Hledger.Cli.Commands.Import
 import Hledger.Cli.Commands.Incomestatement
@@ -86,7 +90,7 @@ builtinCommands = [
   ,(cashflowmode           , cashflow)
   ,(checkdatesmode         , checkdates)
   ,(checkdupesmode         , checkdupes)
-  ,(equitymode             , equity)
+  ,(closemode              , close)
   ,(helpmode               , help')
   ,(importmode             , importcmd)
   ,(incomestatementmode    , incomestatement)
@@ -152,7 +156,7 @@ UIs:
  web                      start web ui
 
 Generating data:
- equity                   generate balance-resetting transactions
+ close                    generate balance-resetting transactions
  interest                 generate interest transactions
  rewrite                  generate automated postings on matched transactions
 
@@ -266,8 +270,8 @@ tests_Hledger_Cli_Commands = TestList [
   
   ,"apply account directive" ~: 
     let ignoresourcepos j = j{jtxns=map (\t -> t{tsourcepos=nullsourcepos}) (jtxns j)} in
-    let sameParse str1 str2 = do j1 <- readJournal Nothing Nothing True Nothing str1 >>= either error' (return . ignoresourcepos)
-                                 j2 <- readJournal Nothing Nothing True Nothing str2 >>= either error' (return . ignoresourcepos)
+    let sameParse str1 str2 = do j1 <- readJournal def Nothing str1 >>= either error' (return . ignoresourcepos)
+                                 j2 <- readJournal def Nothing str2 >>= either error' (return . ignoresourcepos)
                                  j1 `is` j2{jlastreadtime=jlastreadtime j1, jfiles=jfiles j1} --, jparsestate=jparsestate j1}
     in sameParse
                          ("2008/12/07 One\n  alpha  $-1\n  beta  $1\n" <>
@@ -284,13 +288,13 @@ tests_Hledger_Cli_Commands = TestList [
                          )
 
   ,"apply account directive should preserve \"virtual\" posting type" ~: do
-    j <- readJournal Nothing Nothing True Nothing "apply account test\n2008/12/07 One\n  (from)  $-1\n  (to)  $1\n" >>= either error' return
+    j <- readJournal def Nothing "apply account test\n2008/12/07 One\n  (from)  $-1\n  (to)  $1\n" >>= either error' return
     let p = head $ tpostings $ head $ jtxns j
     assertBool "" $ paccount p == "test:from"
     assertBool "" $ ptype p == VirtualPosting
   
   ,"account aliases" ~: do
-    j <- readJournal Nothing Nothing True Nothing "!alias expenses = equity:draw:personal\n1/1\n (expenses:food)  1\n" >>= either error' return
+    j <- readJournal def Nothing "!alias expenses = equity:draw:personal\n1/1\n (expenses:food)  1\n" >>= either error' return
     let p = head $ tpostings $ head $ jtxns j
     assertBool "" $ paccount p == "equity:draw:personal:food"
 
@@ -312,7 +316,7 @@ tests_Hledger_Cli_Commands = TestList [
   --     `is` "aa:aa:aaaaaaaaaaaaaa")
 
   ,"default year" ~: do
-    j <- readJournal Nothing Nothing True Nothing defaultyear_journal_txt >>= either error' return
+    j <- readJournal def Nothing defaultyear_journal_txt >>= either error' return
     tdate (head $ jtxns j) `is` fromGregorian 2009 1 1
     return ()
 
