@@ -233,6 +233,8 @@ Currently, empty cells show 0.
 -}
 
 {-# LANGUAGE OverloadedStrings #-}
+{-# LANGUAGE ExtendedDefaultRules #-}
+{-# LANGUAGE ScopedTypeVariables #-}
 
 module Hledger.Cli.Commands.Balance (
   balancemode
@@ -241,23 +243,26 @@ module Hledger.Cli.Commands.Balance (
  ,balanceReportItemAsText
  ,multiBalanceReportAsText
  ,multiBalanceReportAsCsv
- ,renderBalanceReportTable
+ ,multiBalanceReportAsHtml
+ ,multiBalanceReportHtmlRows
  ,balanceReportAsTable
+ ,balanceReportTableAsText
  ,tests_Hledger_Cli_Commands_Balance
 ) where
 
-import Data.List (intercalate, nub)
+import Control.Monad (when)
+import Data.List
 import Data.Maybe
-import qualified Data.Map as Map
--- import Data.Monoid
+--import qualified Data.Map as Map
 import qualified Data.Text as T
+import qualified Data.Text.Lazy as TL
 import System.Console.CmdArgs.Explicit as C
-import Data.Decimal (roundTo)
+import Lucid as L
 import Text.CSV
 import Test.HUnit
 import Text.Printf (printf)
 import Text.Tabular as T
-import Text.Tabular.AsciiWide
+--import Text.Tabular.AsciiWide
 
 import Hledger
 import Hledger.Cli.CliOptions
@@ -284,9 +289,10 @@ balancemode = (defCommandMode $ ["balance"] ++ aliases) { -- also accept but don
      ,flagNone ["no-elide"] (\opts -> setboolopt "no-elide" opts) "don't squash boring parent accounts (in tree mode)"
      ,flagReq  ["format"] (\s opts -> Right $ setopt "format" s opts) "FORMATSTR" "use this custom line format (in simple reports)"
      ,flagNone ["pretty-tables"] (\opts -> setboolopt "pretty-tables" opts) "use unicode to display prettier tables"
-     ,flagNone ["sort-amount","S"] (\opts -> setboolopt "sort-amount" opts) "sort by amount instead of account name (in flat mode). With multiple columns, sorts by the row total, or by row average if that is displayed."
+     ,flagNone ["sort-amount","S"] (\opts -> setboolopt "sort-amount" opts) "sort by amount instead of account code/name (in flat mode). With multiple columns, sorts by the row total, or by row average if that is displayed."
      ,flagNone ["budget"] (setboolopt "budget") "show performance compared to budget goals defined by periodic transactions"
      ,flagNone ["show-unbudgeted"] (setboolopt "show-unbudgeted") "with --budget, show unbudgeted accounts also"
+     ,flagNone ["invert"] (setboolopt "invert") "display all amounts with reversed sign"
      ]
      ++ outputflags
     ,groupHidden = []
@@ -303,80 +309,48 @@ balance opts@CliOpts{rawopts_=rawopts,reportopts_=ropts} j = do
     Left err -> error' $ unlines [err]
     Right _ -> do
       let format   = outputFormatFromOpts opts
+          budget   = boolopt "budget" rawopts
           interval = interval_ ropts
-      -- XXX shenanigans: use singleBalanceReport or multiBalanceReport when we must, 
-      -- ie when there's a report interval, or when --historical or --cumulative 
-      -- are used (balanceReport doesn't handle those).
-      -- Otherwise prefer the older balanceReport since it can elide boring parents.
-      -- See also compoundBalanceCommandSingleColumnReport, singleBalanceReport etc.
-      case interval of
-        NoInterval -> do
+      case (budget, interval) of
+        (True, _) -> do
+          -- single or multicolumn budget report
+          when (sort_amount_ ropts) $ error' "Sorry, --sort-amount is not yet supported with --budget."  -- TODO
+          reportspan <- reportSpan j ropts
+          let budgetreport     = dbg1 "budgetreport"     $ budgetReport ropts assrt showunbudgeted reportspan d j
+                where
+                  showunbudgeted = boolopt "show-unbudgeted" rawopts
+                  assrt          = not $ ignore_assertions_ $ inputopts_ opts
+              render = case format of
+                "csv"  -> const $ error' "Sorry, CSV output is not yet implemented for this kind of report."  -- TODO
+                "html" -> const $ error' "Sorry, HTML output is not yet implemented for this kind of report."  -- TODO
+                _      -> budgetReportAsText ropts
+          writeOutput opts $ render budgetreport
+          
+        (False, NoInterval) -> do
+          -- single column balance report
           let report
-                -- For --historical/--cumulative, we must use multiBalanceReport.
-                -- (This forces --no-elide.)
                 | balancetype_ ropts `elem` [HistoricalBalance, CumulativeChange]
                   = let ropts' | flat_ ropts = ropts
                                | otherwise   = ropts{accountlistmode_=ALTree}
-                    in singleBalanceReport ropts' (queryFromOpts d ropts) j
-                | otherwise = balanceReport ropts (queryFromOpts d ropts) j
+                    in balanceReportFromMultiBalanceReport ropts' (queryFromOpts d ropts) j
+                          -- for historical balances we must use balanceReportFromMultiBalanceReport (also forces --no-elide)
+                | otherwise = balanceReport ropts (queryFromOpts d ropts) j -- simple Ledger-style balance report 
               render = case format of
-                "csv" -> \ropts r -> (++ "\n") $ printCSV $ balanceReportAsCsv ropts r
-                _     -> balanceReportAsText
+                "csv"  -> \ropts r -> (++ "\n") $ printCSV $ balanceReportAsCsv ropts r
+                "html" -> \_ _ -> error' "Sorry, HTML output is not yet implemented for this kind of report."  -- TODO
+                _      -> balanceReportAsText
           writeOutput opts $ render ropts report
           
-        _ | boolopt "budget" rawopts -> do
-          let budget = budgetJournal opts j
-              j' = budgetRollUp opts budget j
-              report = multiBalanceReport ropts (queryFromOpts d ropts) j'
-              budgetReport = multiBalanceReport ropts (queryFromOpts d ropts) budget
-              render = case format of
-                -- XXX: implement csv rendering
-                "csv" -> (++ "\n") . printCSV . multiBalanceReportAsCsv ropts
-                _     -> multiBalanceReportWithBudgetAsText ropts budgetReport
-          writeOutput opts $ render report
-          
-          | otherwise -> do
+        _  -> do
+          -- multi column balance report
           let report = multiBalanceReport ropts (queryFromOpts d ropts) j
               render = case format of
-                "csv" -> (++ "\n") . printCSV . multiBalanceReportAsCsv ropts
-                _     -> multiBalanceReportAsText ropts
+                "csv"  -> (++ "\n") . printCSV . multiBalanceReportAsCsv ropts
+                "html" ->  (++ "\n") . TL.unpack . L.renderText . multiBalanceReportAsHtml ropts
+                _      -> multiBalanceReportAsText ropts
           writeOutput opts $ render report
 
--- | Re-map account names to closet parent with periodic transaction from budget.
--- Accounts that dont have suitable parent are either remapped to "<unbudgeted>:topAccount" 
--- or left as-is if --show-unbudgeted is provided 
-budgetRollUp :: CliOpts -> Journal -> Journal -> Journal
-budgetRollUp CliOpts{rawopts_=rawopts} budget j = j { jtxns = remapTxn <$> jtxns j }
-    where
-        budgetAccounts = nub $ concatMap (map paccount . ptpostings) $ jperiodictxns budget
-        remapAccount origAcctName = remapAccount' origAcctName
-          where 
-            remapAccount' acctName
-              | acctName `elem` budgetAccounts = acctName
-              | otherwise = 
-                case parentAccountName acctName of
-                  "" | boolopt "show-unbudgeted" rawopts -> origAcctName
-                     | otherwise              -> T.append (T.pack "<unbudgeted>:") acctName
-                  parent -> remapAccount' parent
-        remapPosting p = p { paccount = remapAccount $ paccount p, porigin = Just . fromMaybe p $ porigin p }
-        remapTxn = mapPostings (map remapPosting)
-        mapPostings f t = txnTieKnot $ t { tpostings = f $ tpostings t }
-
--- | Generate journal of all periodic transactions in the given journal for the
--- entireity of its history or reporting period, whatever is smaller
-budgetJournal :: CliOpts -> Journal -> Journal
-budgetJournal opts j = journalBalanceTransactions' opts j { jtxns = budget }
-  where 
-    dates = spanIntersect (jdatespan j) (periodAsDateSpan $ period_ $ reportopts_ opts)
-    budget = [makeBudget t | pt <- jperiodictxns j, t <- runPeriodicTransaction pt dates]
-    makeBudget t = txnTieKnot $ t { tdescription = T.pack "Budget transaction" }
-    journalBalanceTransactions' opts j =
-      let assrt = not . ignore_assertions_ $ inputopts_ opts
-      in
-       either error' id $ journalBalanceTransactions assrt j
-
-
--- single-column balance reports
+-- rendering single-column balance reports
 
 -- | Find the best commodity to convert to when asked to show the
 -- market value of this commodity on the given date. That is, the one
@@ -390,7 +364,7 @@ budgetJournal opts j = journalBalanceTransactions' opts j { jtxns = budget }
 balanceReportAsCsv :: ReportOpts -> BalanceReport -> CSV
 balanceReportAsCsv opts (items, total) =
   ["account","balance"] :
-  [[T.unpack a, showMixedAmountOneLineWithoutPrice b] | (a, _, _, b) <- items]
+  [[T.unpack (maybeAccountNameDrop opts a), showMixedAmountOneLineWithoutPrice b] | (a, _, _, b) <- items]
   ++
   if no_total_ opts
   then []
@@ -503,138 +477,147 @@ renderComponent1 opts (acctname, depth, total) (FormatField ljust min max field)
   TotalField       -> fitStringMulti min max True False $ ((intercalate ", " . map strip . lines) (showamt total))
     where
       showamt | color_ opts = cshowMixedAmountWithoutPrice
-              | otherwise   = showMixedAmountWithoutPrice 
+              | otherwise   = showMixedAmountWithoutPrice
   _                -> ""
 
--- multi-column balance reports
+-- rendering multi-column balance reports
 
 -- | Render a multi-column balance report as CSV.
+-- The CSV will always include the initial headings row,
+-- and will include the final totals row unless --no-total is set.
 multiBalanceReportAsCsv :: ReportOpts -> MultiBalanceReport -> CSV
 multiBalanceReportAsCsv opts (MultiBalanceReport (colspans, items, (coltotals,tot,avg))) =
-  ("account" : "short account" : "indent" : map showDateSpan colspans
-   ++ (if row_total_ opts then ["total"] else [])
-   ++ (if average_ opts then ["average"] else [])
+  ("Account" : map showDateSpan colspans
+   ++ (if row_total_ opts then ["Total"] else [])
+   ++ (if average_ opts then ["Average"] else [])
   ) :
-  [T.unpack a : T.unpack a' : show i :
+  [T.unpack (maybeAccountNameDrop opts a) :
    map showMixedAmountOneLineWithoutPrice
    (amts
     ++ (if row_total_ opts then [rowtot] else [])
     ++ (if average_ opts then [rowavg] else []))
-  | (a,a',i, amts, rowtot, rowavg) <- items]
+  | (a, _, _, amts, rowtot, rowavg) <- items]
   ++
   if no_total_ opts
   then []
-  else [["totals", "", ""]
+  else [["Total:"]
         ++ map showMixedAmountOneLineWithoutPrice (
            coltotals
            ++ (if row_total_ opts then [tot] else [])
            ++ (if average_ opts then [avg] else [])
            )]
 
+-- | Render a multi-column balance report as HTML.
+multiBalanceReportAsHtml :: ReportOpts -> MultiBalanceReport -> Html ()
+multiBalanceReportAsHtml ropts mbr =
+  let
+    (headingsrow,bodyrows,mtotalsrow) = multiBalanceReportHtmlRows ropts mbr
+  in
+    table_ $ mconcat $
+         [headingsrow]
+      ++ bodyrows
+      ++ maybe [] (:[]) mtotalsrow
+
+-- | Render the HTML table rows for a MultiBalanceReport.
+-- Returns the heading row, 0 or more body rows, and the totals row if enabled.
+multiBalanceReportHtmlRows :: ReportOpts -> MultiBalanceReport -> (Html (), [Html ()], Maybe (Html ()))
+multiBalanceReportHtmlRows ropts mbr =
+  let
+    headingsrow:rest = multiBalanceReportAsCsv ropts mbr
+    (bodyrows, mtotalsrow) | no_total_ ropts = (rest,      Nothing)
+                           | otherwise       = (init rest, Just $ last rest)
+  in
+    (multiBalanceReportHtmlHeadRow ropts headingsrow
+    ,map (multiBalanceReportHtmlBodyRow ropts) bodyrows
+    ,multiBalanceReportHtmlFootRow ropts <$> mtotalsrow -- TODO pad totals row with zeros when there are 
+    )
+
+-- | Render one MultiBalanceReport heading row as a HTML table row.
+multiBalanceReportHtmlHeadRow :: ReportOpts -> [String] -> Html ()
+multiBalanceReportHtmlHeadRow _ [] = mempty  -- shouldn't happen
+multiBalanceReportHtmlHeadRow ropts (acct:rest) =
+  let
+    defstyle = style_ ""
+    (amts,tot,avg)
+      | row_total_ ropts && average_ ropts = (init $ init rest, [last $ init rest], [last rest])
+      | row_total_ ropts                   = (init rest,        [last rest],        [])
+      |                     average_ ropts = (init rest,        [],                 [last rest])
+      | otherwise                          = (rest,             [],                 [])
+  in
+    tr_ $ mconcat $
+          td_ [class_ "account"]              (toHtml acct)
+       : [td_ [class_ "", defstyle]           (toHtml a) | a <- amts]
+      ++ [td_ [class_ "rowtotal", defstyle]   (toHtml a) | a <- tot]
+      ++ [td_ [class_ "rowaverage", defstyle] (toHtml a) | a <- avg]
+
+-- | Render one MultiBalanceReport data row as a HTML table row.
+multiBalanceReportHtmlBodyRow :: ReportOpts -> [String] -> Html ()
+multiBalanceReportHtmlBodyRow _ [] = mempty  -- shouldn't happen
+multiBalanceReportHtmlBodyRow ropts (label:rest) =
+  let
+    defstyle = style_ "text-align:right"
+    (amts,tot,avg)
+      | row_total_ ropts && average_ ropts = (init $ init rest, [last $ init rest], [last rest])
+      | row_total_ ropts                   = (init rest,        [last rest],        [])
+      |                     average_ ropts = (init rest,        [],                 [last rest])
+      | otherwise                          = (rest,             [],                 [])
+  in
+    tr_ $ mconcat $
+          td_ [class_ "account", style_ "text-align:left"]  (toHtml label)
+       : [td_ [class_ "amount", defstyle]            (toHtml a) | a <- amts]
+      ++ [td_ [class_ "amount rowtotal", defstyle]   (toHtml a) | a <- tot]
+      ++ [td_ [class_ "amount rowaverage", defstyle] (toHtml a) | a <- avg]
+
+-- | Render one MultiBalanceReport totals row as a HTML table row.
+multiBalanceReportHtmlFootRow :: ReportOpts -> [String] -> Html ()
+multiBalanceReportHtmlFootRow _ropts [] = mempty
+-- TODO pad totals row with zeros when subreport is empty
+--  multiBalanceReportHtmlFootRow ropts $ 
+--     "" 
+--   : repeat nullmixedamt zeros
+--  ++ (if row_total_ ropts then [nullmixedamt] else [])
+--  ++ (if average_ ropts   then [nullmixedamt]   else [])
+multiBalanceReportHtmlFootRow ropts (acct:rest) =
+  let
+    defstyle = style_ "text-align:right"
+    (amts,tot,avg)
+      | row_total_ ropts && average_ ropts = (init $ init rest, [last $ init rest], [last rest])
+      | row_total_ ropts                   = (init rest,        [last rest],        [])
+      |                     average_ ropts = (init rest,        [],                 [last rest])
+      | otherwise                          = (rest,             [],                 [])
+  in
+    tr_ $ mconcat $
+          th_ [style_ "text-align:left"]             (toHtml acct)
+       : [th_ [class_ "amount coltotal", defstyle]   (toHtml a) | a <- amts]
+      ++ [th_ [class_ "amount coltotal", defstyle]   (toHtml a) | a <- tot]
+      ++ [th_ [class_ "amount colaverage", defstyle] (toHtml a) | a <- avg]
+
+--thRow :: [String] -> Html ()
+--thRow = tr_ . mconcat . map (th_ . toHtml)
+
 -- | Render a multi-column balance report as plain text suitable for console output.
 multiBalanceReportAsText :: ReportOpts -> MultiBalanceReport -> String
 multiBalanceReportAsText opts r =
-    printf "%s in %s:\n\n" typeStr (showDateSpan $ multiBalanceReportSpan r)
-      ++ renderBalanceReportTable opts tabl
+    printf "%s in %s:\n\n" desc (showDateSpan $ multiBalanceReportSpan r)
+      ++ balanceReportTableAsText opts tabl
   where
     tabl = balanceReportAsTable opts r
-    typeStr :: String
-    typeStr = case balancetype_ opts of
+    desc = case balancetype_ opts of
         PeriodChange -> "Balance changes"
         CumulativeChange -> "Ending balances (cumulative)"
         HistoricalBalance -> "Ending balances (historical)"
 
--- | Render two multi-column balance reports as plain text suitable for console output.
--- They are assumed to have same number of columns, one of them representing
--- a budget
-multiBalanceReportWithBudgetAsText :: ReportOpts -> MultiBalanceReport -> MultiBalanceReport -> String
-multiBalanceReportWithBudgetAsText opts budget r =
-    printf "%s in %s:\n\n" typeStr (showDateSpan $ multiBalanceReportSpan r)
-      ++ renderBalanceReportTable' opts showcell tabl
-  where
-    tabl = combine (balanceReportAsTable opts r) (balanceReportAsTable opts budget)
-    typeStr :: String
-    typeStr = case balancetype_ opts of
-        PeriodChange -> "Balance changes"
-        CumulativeChange -> "Ending balances (cumulative)"
-        HistoricalBalance -> "Ending balances (historical)"
-    showcell (real, Nothing)     = showamt real
-    showcell (real, Just budget) = 
-      case percentage real budget of
-        Just pct -> printf "%s [%s%% of %s]" (showamt real) (show $ roundTo 0 pct) (showamt budget)
-        Nothing  -> printf "%s [%s]" (showamt real) (showamt budget)
-    percentage real budget =
-      -- percentage of budget consumed is always computed in the cost basis
-      case (toCost real, toCost budget) of
-        (Mixed [a1], Mixed [a2]) 
-          | isReallyZeroAmount a1 -> Just 0 -- if there are no postings, we consumed 0% of budget
-          | acommodity a1 == acommodity a2 && aquantity a2 /= 0 -> 
-            Just $ 100 * aquantity a1 / aquantity a2
-        _ -> Nothing
-        where
-          toCost = normaliseMixedAmount . costOfMixedAmount
-    showamt | color_ opts  = cshowMixedAmountOneLineWithoutPrice
-            | otherwise    = showMixedAmountOneLineWithoutPrice
-    -- combine reportTable budgetTable will combine them into a single table where cells
-    -- are tuples of (actual, Maybe budget) numbers. Main assumptions is that
-    -- row/column titles of budgetTable are subset of row/column titles or reportTable,
-    -- and there are now row/column titles in budgetTable that are not mentioned in reporTable.
-    -- Both of these are satisfied by construction of budget report and process of rolling up
-    -- account names.
-    combine (Table l t d) (Table l' t' d') = Table l t combinedRows
-      where 
-        -- For all accounts that are present in the budget, zip real amounts with budget amounts
-        combinedRows = [ combineRow row budgetRow 
-                       | (acct, row) <- zip (headerContents l) d
-                       , let budgetRow = 
-                               if acct == "" then [] -- "" is totals row
-                               else fromMaybe [] $ Map.lookup acct budgetAccts
-                       ]
-        -- Budget could cover smaller interval of time than the whole journal.
-        -- Headers for budget row will always be a sublist of headers of row
-        combineRow r br =
-          let reportRow = zip (headerContents t) r
-              budgetRow = Map.fromList $ zip (headerContents t') br 
-              findBudgetVal hdr = Map.lookup hdr budgetRow 
-          in map (\(hdr, val) -> (val, findBudgetVal hdr)) reportRow
-        budgetAccts = Map.fromList $ zip (headerContents l') d'
-                                                           
--- | Given a table representing a multi-column balance report (for example,
--- made using 'balanceReportAsTable'), render it in a format suitable for
--- console output.
-renderBalanceReportTable :: ReportOpts -> Table String String MixedAmount -> String
-renderBalanceReportTable ropts = 
-  renderBalanceReportTable' ropts showamt
-  where
-    showamt | color_ ropts = cshowMixedAmountOneLineWithoutPrice
-            | otherwise    = showMixedAmountOneLineWithoutPrice
-  
-renderBalanceReportTable' :: ReportOpts -> (a -> String) -> Table String String a -> String
-renderBalanceReportTable' (ReportOpts { pretty_tables_ = pretty}) showCell = 
-  unlines
-  . addtrailingblank
-  . trimborder 
-  . lines
-  . render pretty id id showCell
-  . align
-  where
-    addtrailingblank = (++[""])
-    trimborder = drop 1 . init . map (drop 1 . init)
-    align (Table l t d) = Table l' t d
-      where
-        acctswidth = maximum' $ map strWidth (headerContents l)
-        l'         = padRightWide acctswidth <$> l
-
 -- | Build a 'Table' from a multi-column balance report.
 balanceReportAsTable :: ReportOpts -> MultiBalanceReport -> Table String String MixedAmount
 balanceReportAsTable opts (MultiBalanceReport (colspans, items, (coltotals,tot,avg))) =
-   addtotalrow $ Table
+   addtotalrow $ 
+   Table
      (T.Group NoLine $ map Header accts)
      (T.Group NoLine $ map Header colheadings)
      (map rowvals items)
   where
     mkDate = case balancetype_ opts of
-       PeriodChange -> showDateSpan
+       PeriodChange -> showDateSpanMonthAbbrev
        _            -> maybe "" (showDate . prevday) . spanEnd
     colheadings = map mkDate colspans
                   ++ (if row_total_ opts then ["  Total"] else [])
@@ -653,10 +636,14 @@ balanceReportAsTable opts (MultiBalanceReport (colspans, items, (coltotals,tot,a
                                     ++ (if average_ opts && not (null coltotals)   then [avg] else [])
                                     ))
 
--- | Figure out the overall date span of a multicolumn balance report.
-multiBalanceReportSpan :: MultiBalanceReport -> DateSpan
-multiBalanceReportSpan (MultiBalanceReport ([], _, _))       = DateSpan Nothing Nothing
-multiBalanceReportSpan (MultiBalanceReport (colspans, _, _)) = DateSpan (spanStart $ head colspans) (spanEnd $ last colspans)
+-- | Given a table representing a multi-column balance report (for example,
+-- made using 'balanceReportAsTable'), render it in a format suitable for
+-- console output.
+balanceReportTableAsText :: ReportOpts -> Table String String MixedAmount -> String
+balanceReportTableAsText ropts = tableAsText ropts showamt
+  where
+    showamt | color_ ropts = cshowMixedAmountOneLineWithoutPrice
+            | otherwise    =  showMixedAmountOneLineWithoutPrice
 
 
 tests_Hledger_Cli_Commands_Balance = TestList
