@@ -27,11 +27,26 @@ This command displays a simple balance sheet, showing historical ending
 balances of asset and liability accounts (ignoring any report begin date). 
 It assumes that these accounts are under a top-level `asset` or `liability`
 account (case insensitive, plural forms also  allowed).
+
+Note this report shows all account balances with normal positive sign
+(like conventional financial statements, unlike balance/print/register)
+(experimental).
   |],
   cbctitle    = "Balance Sheet",
-  cbcqueries  = [ ("Assets"     , journalAssetAccountQuery,     Just NormalPositive),
-                  ("Liabilities", journalLiabilityAccountQuery, Just NormalNegative)
-                ],
+  cbcqueries  = [
+     CBCSubreportSpec{
+      cbcsubreporttitle="Assets"
+     ,cbcsubreportquery=journalAssetAccountQuery
+     ,cbcsubreportnormalsign=NormallyPositive
+     ,cbcsubreportincreasestotal=True
+     }
+    ,CBCSubreportSpec{
+      cbcsubreporttitle="Liabilities"
+     ,cbcsubreportquery=journalLiabilityAccountQuery
+     ,cbcsubreportnormalsign=NormallyNegative
+     ,cbcsubreportincreasestotal=False
+     }
+    ],
   cbctype     = HistoricalBalance
 }
 
